@@ -1,7 +1,7 @@
 #!/bin/sh
 
 # Test whether a specific UTF-8 locale is installed.
-: ${LOCALE_FR_UTF8=fr_FR.UTF-8}
+: "${LOCALE_FR_UTF8=fr_FR.UTF-8}"
 if test $LOCALE_FR_UTF8 = none; then
   if test -f /usr/bin/localedef; then
     echo "Skipping test: no french Unicode locale is installed"
@@ -12,4 +12,4 @@ if test $LOCALE_FR_UTF8 = none; then
 fi
 
 LC_ALL=$LOCALE_FR_UTF8 \
-./test-mbsrtowcs${EXEEXT} 2
+${CHECKER} ./test-mbsrtowcs${EXEEXT} 2
