@@ -196,7 +196,7 @@ pr_context_hunk (struct change *hunk)
     last1 = files[1].valid_lines - 1;
 
   /* If desired, find the preceding function definition line in file 0.  */
-  function = NULL;
+  function = nullptr;
   if (function_regexp.fastmap)
     function = find_function (files[0].linbuf, first0);
 
@@ -345,7 +345,7 @@ pr_unidiff_hunk (struct change *hunk)
     last1 = files[1].valid_lines - 1;
 
   /* If desired, find the preceding function definition line in file 0.  */
-  function = NULL;
+  function = nullptr;
   if (function_regexp.fastmap)
     function = find_function (files[0].linbuf, first0);
 
@@ -379,7 +379,7 @@ pr_unidiff_hunk (struct change *hunk)
           char const *const *line = &files[0].linbuf[i++];
           if (! (suppress_blank_empty && **line == '\n'))
             putc (initial_tab ? '\t' : ' ', out);
-          print_1_line (NULL, line);
+          print_1_line (nullptr, line);
           j++;
         }
       else
@@ -395,7 +395,7 @@ pr_unidiff_hunk (struct change *hunk)
               putc ('-', out);
               if (initial_tab && ! (suppress_blank_empty && **line == '\n'))
                 putc ('\t', out);
-              print_1_line_nl (NULL, line, true);
+              print_1_line_nl (nullptr, line, true);
 
               set_color_context (RESET_CONTEXT);
 
@@ -414,7 +414,7 @@ pr_unidiff_hunk (struct change *hunk)
               putc ('+', out);
               if (initial_tab && ! (suppress_blank_empty && **line == '\n'))
                 putc ('\t', out);
-              print_1_line_nl (NULL, line, true);
+              print_1_line_nl (nullptr, line, true);
 
               set_color_context (RESET_CONTEXT);
 
@@ -481,7 +481,7 @@ mark_ignorable (struct change *script)
       lin first0, last0, first1, last1;
 
       /* Turn this change into a hunk: detach it from the others.  */
-      script->link = NULL;
+      script->link = nullptr;
 
       /* Determine whether this change is ignorable.  */
       script->ignore = ! analyze_hunk (script,
@@ -497,7 +497,7 @@ mark_ignorable (struct change *script)
 
 /* Find the last function-header line in LINBUF prior to line number LINENUM.
    This is a line containing a match for the regexp in 'function_regexp'.
-   Return the address of the text, or NULL if no function-header is found.  */
+   Return the address of the text, or null if no function-header is found.  */
 
 static char const *
 find_function (char const * const *linbuf, lin linenum)
@@ -516,7 +516,7 @@ find_function (char const * const *linbuf, lin linenum)
 	 to LEN = LINELEN and no machine code is generated.  */
       regoff_t len = MIN (linelen, TYPE_MAXIMUM (regoff_t));
 
-      if (0 <= re_search (&function_regexp, line, len, 0, len, NULL))
+      if (0 <= re_search (&function_regexp, line, len, 0, len, nullptr))
         {
           find_function_last_match = i;
           return line;
@@ -527,5 +527,5 @@ find_function (char const * const *linbuf, lin linenum)
   if (find_function_last_match != LIN_MAX)
     return linbuf[find_function_last_match];
 
-  return NULL;
+  return nullptr;
 }
