@@ -45,7 +45,7 @@
 #include <xstdopen.h>
 
 /* The official name of this program (e.g., no 'g' prefix).  */
-#define PROGRAM_NAME "diff3"
+static char const PROGRAM_NAME[] = "diff3";
 
 #define AUTHORS \
   proper_name ("Randy Smith")
@@ -54,22 +54,18 @@
    data structures for both diff3 diffs and normal diffs.  */
 
 /* Different files within a three way diff.  */
-#define	FILE0	0
-#define	FILE1	1
-#define	FILE2	2
+enum { FILE0, FILE1, FILE2 };
 
 /* A three way diff is built from two two-way diffs; the file which
    the two two-way diffs share is:  */
-#define	FILEC	FILE2
+enum { FILEC = FILE2 };
 
 /* Different files within a two way diff.
    FC is the common file, FO the other file.  */
-#define FO 0
-#define FC 1
+enum { FO, FC };
 
 /* The ranges are indexed by */
-#define	RANGE_START	0
-#define	RANGE_END	1
+enum { RANGE_START, RANGE_END };
 
 enum diff_type {
   DIFF_ERROR,			/* Should not be used */
@@ -103,7 +99,11 @@ struct diff3_block {
   struct diff3_block *next;
 };
 
-/* Access the ranges on a diff block.  */
+/* The following are macros, not functions, as they may be used as
+   lvalues, or they may be polymorphic in that they work with either
+   diff or diff3 blocks.  */
+
+/* Access the ranges on a diff or diff3 block.  */
 #define	D_LOWLINE(diff, filenum)	\
   ((diff)->ranges[filenum][RANGE_START])
 #define	D_HIGHLINE(diff, filenum)	\
@@ -111,7 +111,7 @@ struct diff3_block {
 #define	D_NUMLINES(diff, filenum)	\
   (D_HIGHLINE (diff, filenum) - D_LOWLINE (diff, filenum) + 1)
 
-/* Access the line numbers in a file in a diff by relative line
+/* Access the line numbers in a file in a diff or diff3 block by relative line
    numbers (i.e. line number within the diff itself).  Note that these
    are lvalues and can be used for assignment.  */
 #define	D_RELNUM(diff, filenum, linenum)	\
@@ -125,23 +125,23 @@ struct diff3_block {
 #define	D_LENARRAY(diff, filenum)	\
   ((diff)->lengths[filenum])
 
-/* Next block.  */
+/* Next diff or diff3 block.  */
 #define	D_NEXT(diff)	((diff)->next)
 
 /* Access the type of a diff3 block.  */
 #define	D3_TYPE(diff)	((diff)->correspond)
 
-/* Line mappings based on diffs.  The first maps off the top of the
-   diff, the second off of the bottom.  */
+/* Line mappings based on diff or diff3 blocks.  The first maps off
+   the top of the diff, the second off of the bottom.  */
 #define	D_HIGH_MAPLINE(diff, fromfile, tofile, linenum)	\
   ((linenum)						\
-   - D_HIGHLINE ((diff), (fromfile))			\
-   + D_HIGHLINE ((diff), (tofile)))
+   - D_HIGHLINE (diff, fromfile)			\
+   + D_HIGHLINE (diff, tofile))
 
 #define	D_LOW_MAPLINE(diff, fromfile, tofile, linenum)	\
   ((linenum)						\
-   - D_LOWLINE ((diff), (fromfile))			\
-   + D_LOWLINE ((diff), (tofile)))
+   - D_LOWLINE (diff, fromfile)				\
+   + D_LOWLINE (diff, tofile))
 
 /* Options variables for flags set on command line.  */
 
@@ -273,7 +273,6 @@ main (int argc, char **argv)
   char *tag_strings[3];
   char *commonname;
   char **file;
-  struct stat statb;
 
   exit_failure = EXIT_TROUBLE;
   initialize_main (&argc, &argv);
@@ -329,7 +328,7 @@ main (int argc, char **argv)
           break;
         case 'v':
           version_etc (stdout, PROGRAM_NAME, PACKAGE_NAME, Version,
-                       AUTHORS, (char *) NULL);
+                       AUTHORS, nullptr);
           check_stdout ();
           return EXIT_SUCCESS;
         case DIFF_PROGRAM_OPTION:
@@ -411,15 +410,6 @@ main (int argc, char **argv)
   for (i = 0; i < 3; i++)
     rev_mapping[mapping[i]] = i;
 
-  for (i = 0; i < 3; i++)
-    if (! STREQ (file[i], "-"))
-      {
-        if (stat (file[i], &statb) < 0)
-          perror_with_exit (file[i]);
-        else if (S_ISDIR (statb.st_mode))
-          die (EXIT_TROUBLE, EISDIR, "%s", file[i]);
-      }
-
 #ifdef SIGCHLD
   /* System V fork+wait does not work if SIGCHLD is ignored.  */
   signal (SIGCHLD, SIG_DFL);
@@ -1091,7 +1081,7 @@ process_diff (char const *filea,
       block_list_end = &bptr->next;
     }
 
-  *block_list_end = NULL;
+  *block_list_end = nullptr;
   return block_list;
 }
 
@@ -1213,7 +1203,7 @@ read_diff (char const *filea,
   int fd, wstatus, status;
   int werrno = 0;
   struct stat pipestat;
-  char const *argv[9];
+  char const *argv[10];
   char const **ap;
 #if HAVE_WORKING_FORK
   int fds[2];
@@ -1230,6 +1220,7 @@ read_diff (char const *filea,
   if (strip_trailing_cr)
     *ap++ = "--strip-trailing-cr";
   *ap++ = "--horizon-lines=100";
+  *ap++ = "---no-directory";
   *ap++ = "--";
   *ap++ = filea;
   *ap++ = fileb;
@@ -1276,9 +1267,9 @@ read_diff (char const *filea,
 
 #endif
 
-  if (fstat (fd, &pipestat) != 0)
-    perror_with_exit ("fstat");
-  current_chunk_size = MAX (1, STAT_BLOCKSIZE (pipestat));
+  current_chunk_size = (fstat (fd, &pipestat) == 0
+                        ? MAX (1, STAT_BLOCKSIZE (pipestat))
+                        : 8 * 1024);
   diff_result = xmalloc (current_chunk_size);
   total = 0;
 
