@@ -1,6 +1,6 @@
 /* sdiff-format output routines for GNU DIFF.
 
-   Copyright (C) 1991-1993, 1998, 2001-2002, 2004, 2009-2013, 2015-2018 Free
+   Copyright (C) 1991-1993, 1998, 2001-2002, 2004, 2009-2013, 2015-2023 Free
    Software Foundation, Inc.
 
    This file is part of GNU DIFF.
@@ -55,8 +55,8 @@ tab_from_to (size_t from, size_t to)
   if (!expand_tabs)
     for (tab = from + tab_size - from % tab_size;  tab <= to;  tab += tab_size)
       {
-	putc ('\t', out);
-	from = tab;
+        putc ('\t', out);
+        from = tab;
       }
   while (from++ < to)
     putc (' ', out);
@@ -83,111 +83,111 @@ print_half_line (char const *const *line, size_t indent, size_t out_bound)
       register char c = *text_pointer++;
 
       switch (c)
-	{
-	case '\t':
-	  {
-	    size_t spaces = tabsize - in_position % tabsize;
-	    if (in_position == out_position)
-	      {
-		size_t tabstop = out_position + spaces;
-		if (expand_tabs)
-		  {
-		    if (out_bound < tabstop)
-		      tabstop = out_bound;
-		    for (;  out_position < tabstop;  out_position++)
-		      putc (' ', out);
-		  }
-		else
-		  if (tabstop < out_bound)
-		    {
-		      out_position = tabstop;
-		      putc (c, out);
-		    }
-	      }
-	    in_position += spaces;
-	  }
-	  break;
+        {
+        case '\t':
+          {
+            size_t spaces = tabsize - in_position % tabsize;
+            if (in_position == out_position)
+              {
+                size_t tabstop = out_position + spaces;
+                if (expand_tabs)
+                  {
+                    if (out_bound < tabstop)
+                      tabstop = out_bound;
+                    for (;  out_position < tabstop;  out_position++)
+                      putc (' ', out);
+                  }
+                else
+                  if (tabstop < out_bound)
+                    {
+                      out_position = tabstop;
+                      putc (c, out);
+                    }
+              }
+            in_position += spaces;
+          }
+          break;
 
-	case '\r':
-	  {
-	    putc (c, out);
-	    tab_from_to (0, indent);
-	    in_position = out_position = 0;
-	  }
-	  break;
+        case '\r':
+          {
+            putc (c, out);
+            tab_from_to (0, indent);
+            in_position = out_position = 0;
+          }
+          break;
 
-	case '\b':
-	  if (in_position != 0 && --in_position < out_bound)
-	    {
-	      if (out_position <= in_position)
-		/* Add spaces to make up for suppressed tab past out_bound.  */
-		for (;  out_position < in_position;  out_position++)
-		  putc (' ', out);
-	      else
-		{
-		  out_position = in_position;
-		  putc (c, out);
-		}
-	    }
-	  break;
+        case '\b':
+          if (in_position != 0 && --in_position < out_bound)
+            {
+              if (out_position <= in_position)
+                /* Add spaces to make up for suppressed tab past out_bound.  */
+                for (;  out_position < in_position;  out_position++)
+                  putc (' ', out);
+              else
+                {
+                  out_position = in_position;
+                  putc (c, out);
+                }
+            }
+          break;
 
-	default:
-	  {
-	    wchar_t wc;
-	    size_t bytes = mbrtowc (&wc, tp0, text_limit - tp0, &mbstate);
+        default:
+          {
+            wchar_t wc;
+            size_t bytes = mbrtowc (&wc, tp0, text_limit - tp0, &mbstate);
 
-	    if (0 < bytes && bytes < (size_t) -2)
-	      {
-		int width = wcwidth (wc);
-		if (0 < width)
-		  in_position += width;
-		if (in_position <= out_bound)
-		  {
-		    out_position = in_position;
-		    fwrite (tp0, 1, bytes, stdout);
-		  }
-		text_pointer = tp0 + bytes;
-		break;
-	      }
-	  }
-	  FALLTHROUGH;
-	case '\f':
-	case '\v':
-	  if (in_position < out_bound)
-	    putc (c, out);
-	  break;
+            if (0 < bytes && bytes < (size_t) -2)
+              {
+                int width = wcwidth (wc);
+                if (0 < width)
+                  in_position += width;
+                if (in_position <= out_bound)
+                  {
+                    out_position = in_position;
+                    fwrite (tp0, 1, bytes, stdout);
+                  }
+                text_pointer = tp0 + bytes;
+                break;
+              }
+          }
+          FALLTHROUGH;
+        case '\f':
+        case '\v':
+          if (in_position < out_bound)
+            putc (c, out);
+          break;
 
-	case ' ': case '!': case '"': case '#': case '%':
-	case '&': case '\'': case '(': case ')': case '*':
-	case '+': case ',': case '-': case '.': case '/':
-	case '0': case '1': case '2': case '3': case '4':
-	case '5': case '6': case '7': case '8': case '9':
-	case ':': case ';': case '<': case '=': case '>':
-	case '?':
-	case 'A': case 'B': case 'C': case 'D': case 'E':
-	case 'F': case 'G': case 'H': case 'I': case 'J':
-	case 'K': case 'L': case 'M': case 'N': case 'O':
-	case 'P': case 'Q': case 'R': case 'S': case 'T':
-	case 'U': case 'V': case 'W': case 'X': case 'Y':
-	case 'Z':
-	case '[': case '\\': case ']': case '^': case '_':
-	case 'a': case 'b': case 'c': case 'd': case 'e':
-	case 'f': case 'g': case 'h': case 'i': case 'j':
-	case 'k': case 'l': case 'm': case 'n': case 'o':
-	case 'p': case 'q': case 'r': case 's': case 't':
-	case 'u': case 'v': case 'w': case 'x': case 'y':
-	case 'z': case '{': case '|': case '}': case '~':
-	  /* These characters are printable ASCII characters.  */
-	  if (in_position++ < out_bound)
-	    {
-	      out_position = in_position;
-	      putc (c, out);
-	    }
-	  break;
+        case ' ': case '!': case '"': case '#': case '%':
+        case '&': case '\'': case '(': case ')': case '*':
+        case '+': case ',': case '-': case '.': case '/':
+        case '0': case '1': case '2': case '3': case '4':
+        case '5': case '6': case '7': case '8': case '9':
+        case ':': case ';': case '<': case '=': case '>':
+        case '?':
+        case 'A': case 'B': case 'C': case 'D': case 'E':
+        case 'F': case 'G': case 'H': case 'I': case 'J':
+        case 'K': case 'L': case 'M': case 'N': case 'O':
+        case 'P': case 'Q': case 'R': case 'S': case 'T':
+        case 'U': case 'V': case 'W': case 'X': case 'Y':
+        case 'Z':
+        case '[': case '\\': case ']': case '^': case '_':
+        case 'a': case 'b': case 'c': case 'd': case 'e':
+        case 'f': case 'g': case 'h': case 'i': case 'j':
+        case 'k': case 'l': case 'm': case 'n': case 'o':
+        case 'p': case 'q': case 'r': case 's': case 't':
+        case 'u': case 'v': case 'w': case 'x': case 'y':
+        case 'z': case '{': case '|': case '}': case '~':
+          /* These characters are printable ASCII characters.  */
+          if (in_position++ < out_bound)
+            {
+              out_position = in_position;
+              putc (c, out);
+            }
+          break;
 
-	case '\n':
-	  return out_position;
-	}
+        case '\n':
+          return out_position;
+        }
     }
 
   return out_position;
@@ -199,7 +199,7 @@ print_half_line (char const *const *line, size_t indent, size_t out_bound)
 
 static void
 print_1sdiff_line (char const *const *left, char sep,
-		   char const *const *right)
+                   char const *const *right)
 {
   FILE *out = outfile;
   size_t hw = sdiff_half_width;
@@ -229,7 +229,7 @@ print_1sdiff_line (char const *const *left, char sep,
     {
       col = tab_from_to (col, (hw + c2o - 1) / 2) + 1;
       if (sep == '|' && put_newline != (right[1][-1] == '\n'))
-	sep = put_newline ? '/' : '\\';
+        sep = put_newline ? '/' : '\\';
       putc (sep, out);
     }
 
@@ -237,10 +237,10 @@ print_1sdiff_line (char const *const *left, char sep,
     {
       put_newline |= right[1][-1] == '\n';
       if (**right != '\n')
-	{
-	  col = tab_from_to (col, c2o);
-	  print_half_line (right, col, hw);
-	}
+        {
+          col = tab_from_to (col, c2o);
+          print_half_line (right, col, hw);
+        }
     }
 
   if (put_newline)
@@ -259,22 +259,18 @@ print_sdiff_common_lines (lin limit0, lin limit1)
   if (!suppress_common_lines && (i0 != limit0 || i1 != limit1))
     {
       if (sdiff_merge_assist)
-	{
-	  printint len0 = limit0 - i0;
-	  printint len1 = limit1 - i1;
-	  fprintf (outfile, "i%"pI"d,%"pI"d\n", len0, len1);
-	}
+	fprintf (outfile, "i%"pI"d,%"pI"d\n", limit0 - i0, limit1 - i1);
 
       if (!left_column)
-	{
-	  while (i0 != limit0 && i1 != limit1)
-	    print_1sdiff_line (&files[0].linbuf[i0++], ' ',
-			       &files[1].linbuf[i1++]);
-	  while (i1 != limit1)
-	    print_1sdiff_line (0, ')', &files[1].linbuf[i1++]);
-	}
+        {
+          while (i0 != limit0 && i1 != limit1)
+            print_1sdiff_line (&files[0].linbuf[i0++], ' ',
+                               &files[1].linbuf[i1++]);
+          while (i1 != limit1)
+            print_1sdiff_line (0, ')', &files[1].linbuf[i1++]);
+        }
       while (i0 != limit0)
-	print_1sdiff_line (&files[0].linbuf[i0++], '(', 0);
+        print_1sdiff_line (&files[0].linbuf[i0++], '(', 0);
     }
 
   next0 = limit0;
@@ -301,17 +297,15 @@ print_sdiff_hunk (struct change *hunk)
   print_sdiff_common_lines (first0, first1);
 
   if (sdiff_merge_assist)
-    {
-      printint len0 = last0 - first0 + 1;
-      printint len1 = last1 - first1 + 1;
-      fprintf (outfile, "c%"pI"d,%"pI"d\n", len0, len1);
-    }
+    fprintf (outfile, "c%"pI"d,%"pI"d\n",
+	     last0 - first0 + 1,
+	     last1 - first1 + 1);
 
   /* Print "xxx  |  xxx " lines.  */
   if (changes == CHANGED)
     {
       for (i = first0, j = first1;  i <= last0 && j <= last1;  i++, j++)
-	print_1sdiff_line (&files[0].linbuf[i], '|', &files[1].linbuf[j]);
+        print_1sdiff_line (&files[0].linbuf[i], '|', &files[1].linbuf[j]);
       changes = (i <= last0 ? OLD : 0) + (j <= last1 ? NEW : 0);
       next0 = first0 = i;
       next1 = first1 = j;
@@ -321,7 +315,7 @@ print_sdiff_hunk (struct change *hunk)
   if (changes & NEW)
     {
       for (j = first1; j <= last1; ++j)
-	print_1sdiff_line (0, '>', &files[1].linbuf[j]);
+        print_1sdiff_line (0, '>', &files[1].linbuf[j]);
       next1 = j;
     }
 
@@ -329,7 +323,7 @@ print_sdiff_hunk (struct change *hunk)
   if (changes & OLD)
     {
       for (i = first0; i <= last0; ++i)
-	print_1sdiff_line (&files[0].linbuf[i], '<', 0);
+        print_1sdiff_line (&files[0].linbuf[i], '<', 0);
       next0 = i;
     }
 }
